/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef YOU_WANT_ME_TO_GO_BACK_TO_MY_PLANE_AND_GO_BACK_TO_FRANCE_H__
#define YOU_WANT_ME_TO_GO_BACK_TO_MY_PLANE_AND_GO_BACK_TO_FRANCE_H__

#include <gtk/gtk.h>

void exit_dialog(GtkWidget *widget, gpointer data);


#endif


